@@ -1,11 +1,18 @@
+# SPDX-FileCopyrightText: 2022 The meson-python developers
+#
+# SPDX-License-Identifier: MIT
+
 import subprocess
 import sys
 
 import pytest
 
-from .conftest import cd_package, in_git_repo_context
+from mesonpy._util import chdir
+
+from .conftest import in_git_repo_context, package_dir
 
 
+@pytest.mark.usefixtures('pep518')
 @pytest.mark.parametrize(
     ('package'),
     [
@@ -15,9 +22,9 @@ from .conftest import cd_package, in_git_repo_context
 @pytest.mark.parametrize(
     'build_arg', ['', '--wheel'], ids=['sdist_to_wheel', 'wheel_directly']
 )
-def test_pep518(pep518, package, build_arg, tmp_path):
+def test_pep518(package, build_arg, tmp_path):
     dist = tmp_path / 'dist'
 
-    with cd_package(package), in_git_repo_context():
+    with chdir(package_dir / package), in_git_repo_context():
         build_args = [build_arg] if build_arg else []
         subprocess.run([sys.executable, '-m', 'build', '--outdir', str(dist), *build_args], check=True)
